==============
geocube README
==============

Tool to convert geopandas vector data into rasterized xarray data.

.. image:: https://badges.gitter.im/corteva--geocube/community.svg
   :alt: Join the chat at https://gitter.im/corteva--geocube/community
   :target: https://gitter.im/corteva--geocube/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

.. image:: https://img.shields.io/badge/all_contributors-12-orange.svg?style=flat-square
    :alt: All Contributors
    :target: https://github.com/corteva/geocube/blob/master/AUTHORS.rst

.. image:: https://img.shields.io/badge/license-BSD%203--Clause-yellow.svg
    :target: https://github.com/corteva/geocube/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/geocube.svg
    :target: https://pypi.python.org/pypi/geocube

.. image:: https://pepy.tech/badge/geocube
    :target: https://pepy.tech/project/geocube

.. image:: https://img.shields.io/conda/vn/conda-forge/geocube.svg
    :target: https://anaconda.org/conda-forge/geocube

.. image:: https://github.com/corteva/geocube/workflows/Tests/badge.svg
    :target: https://github.com/corteva/geocube/actions?query=workflow%3ATests

.. image:: https://ci.appveyor.com/api/projects/status/bjxhlbt5tjsonwo8/branch/master?svg=true
    :target: https://ci.appveyor.com/project/snowman2/geocube

.. image:: https://codecov.io/gh/corteva/geocube/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/corteva/geocube

.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
    :target: https://github.com/pre-commit/pre-commit

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/python/black


.. image:: https://zenodo.org/badge/179524523.svg
    :target: https://zenodo.org/badge/latestdoi/179524523


Documentation
-------------

- Stable: https://corteva.github.io/geocube/stable/
- Latest: https://corteva.github.io/geocube/latest/

Bugs/Questions
--------------

- Report bugs/feature requests: https://github.com/corteva/geocube/issues
- Ask questions: https://github.com/corteva/geocube/discussions
- Ask developer questions: https://gitter.im/corteva--geocube/community
- Ask questions from the GIS community: https://gis.stackexchange.com/questions/tagged/geocube

Credits
-------

This package was originally templated with with Cookiecutter_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
